@@ -6,5 +6,5 @@ from veracode_api_py.dynamic import Analyses, Scans, CodeGroups, Configuration,
 from veracode_api_py.findings import Findings, SummaryReport
 from veracode_api_py.healthcheck import Healthcheck
 from veracode_api_py.identity import Users, Teams, BusinessUnits, APICredentials, Roles
-from veracode_api_py.sca import Workspaces
+from veracode_api_py.sca import Workspaces, ComponentActivity
 from veracode_api_py.exceptions import VeracodeError, VeracodeAPIError
\ No newline at end of file
